@@ -57,16 +57,16 @@ init_powerprefs (struct basedata *base)
 	/* setup IPC system for clients */
 	if ((rc = ipc_init ("PowerPrefs", LIBMODE_CLIENT, CLIENT_REGISTER)) != 0) {
 		if (rc == E_NOSERVER)
-			print_error (_("ERROR: Server message port not found. Server isn't running.\n"));
+			print_msg (PBB_ERR, _("Server message port not found. Server isn't running.\n"));
 		else if (rc == E_REGISTER)
-			print_error (_("ERROR: Sending registration to server failed.\n"));
+			print_msg (PBB_ERR, _("Sending registration to server failed.\n"));
 		else if (rc == E_MSGPORT)
-			print_error (_("ERROR: Can't create message port for client.\n"));
+			print_msg (PBB_ERR, _("Can't create message port for client.\n"));
 		return rc;
 	}
 
 	if ((base->taglist = (struct tagitem*) malloc (TAGBUFFERLEN)) == NULL) {
-		print_error (_("ERROR: Out of memory.\n"));
+		print_msg (PBB_ERR, _("Out of memory.\n"));
 		return E_NOMEM;
 	}
 	taglist_init (base->taglist);
@@ -128,7 +128,7 @@ install_sighandler ()
 		if (!sigaction (SIGTERM, &sa, NULL))
 			return 0;
 	
-	print_error(_("ERROR: Can't install signal handler\n"));
+	print_msg (PBB_ERR, _("Can't install signal handler\n"));
 	return -1;
 }
 
@@ -306,7 +306,7 @@ init_guicontrol (struct basedata *base)
 
 	count = sizeof(GT) / sizeof(struct GTItem);
 	if ((base->GUIControl = (struct GUIControlItem*) malloc (count*sizeof(struct GUIControlItem))) == NULL) {
-		print_error (_("ERROR: Out of memory.\n"));
+		print_msg (PBB_ERR, _("Out of memory.\n"));
 		return E_NOMEM;
 	}
 
@@ -424,7 +424,7 @@ collect_kbd_devices(struct basedata *base)
 			} else
 				close(fd);
 /*		} else if (errno != ENOENT) {
-			print_error(_("WARNING: Problems accessing event device 'event%d': %s\n"), i, strerror(errno));
+			print_msg (PBB_WARN, _("Problems accessing event device 'event%d': %s\n"), i, strerror(errno));
 */
 		}
 	}
